==> qtermwidget-1.0.0.tar.xz: qtermwidget-1.0.0/lib/translations/qtermwidget_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="454"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>Jelzés a &apos;%1&apos; munkamenetben</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="606"/>
        <source>Session &apos;%1&apos; exited with status %2.</source>
        <translation>A(z) &apos;%1&apos; munkamenet %2 állapottal lépett ki.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="608"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>A(z) &apos;%1&apos; munkamenet összeomlott.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="613"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>A &apos;%1&apos; munkamenet váratlanul kilépett.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1279"/>
        <source>Size: XXX x XXX</source>
        <translation>Méret: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1291"/>
        <source>Size: %1 x %2</source>
        <translation>Méret: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2741"/>
        <source>Paste multiline text</source>
        <translation>Többsoros szöveg beillesztése</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2742"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Biztosan beilleszti ezt a szöveget?</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3241"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;A kimenet &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;fel van függesztve&lt;/a&gt; a Ctrl+S megnyomásával.  Nyomjon &lt;b&gt;Ctrl+Q-t&lt;/b&gt; a folytatáshoz.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1121"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Nincs elérhető billentyűzet-átalakító.  Hiányzik az információ, amely a billentyű lenyomások a terminálhoz küldendő karakterekké alakításához szükséges.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2748"/>
        <source>Show Details...</source>
        <translation>Részletek megjelenítése...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="278"/>
        <location filename="../ColorScheme.cpp" line="293"/>
        <source>Un-named Color Scheme</source>
        <translation>Névtelen Színséma</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="464"/>
        <source>Accessible Color Scheme</source>
        <translation>Elérhető színséma</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="515"/>
        <source>Open Link</source>
        <translation>Link megnyitása</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="516"/>
        <source>Copy Link Address</source>
        <translation>Link másolása</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Send Email To...</source>
        <translation>Email küldése ...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Email Address</source>
        <translation>Email cím másolása</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="468"/>
        <source>Color Scheme Error</source>
        <translation>Színséma hiba</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="469"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Nem sikerült betölteni a színsémát. %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="40"/>
        <source>Match case</source>
        <translation>Nagybetűérzékeny</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="46"/>
        <source>Regular expression</source>
        <translation>Reguláris kifejezés</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="50"/>
        <source>Highlight all matches</source>
        <translation>Találatok kiemelése</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Keresősáv</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qtermwidget-2.2.0.tar.xz: qtermwidget-2.2.0/lib/translations/qtermwidget_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="448"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>Jelzés a &apos;%1&apos; munkamenetben</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="630"/>
        <source>Session &apos;%1&apos; exited with code %2.</source>
        <translation>A munkamenet &apos;%1&apos; kilépett ezzel a kóddal %2.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="632"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>A(z) &apos;%1&apos; munkamenet összeomlott.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="637"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>A &apos;%1&apos; munkamenet váratlanul kilépett.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1311"/>
        <source>Size: XXX x XXX</source>
        <translation>Méret: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1323"/>
        <source>Size: %1 x %2</source>
        <translation>Méret: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2987"/>
        <source>Paste multiline text</source>
        <translation>Többsoros szöveg beillesztése</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2988"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Biztosan beilleszti ezt a szöveget?</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3459"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;A kimenet &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;fel van függesztve&lt;/a&gt; a Ctrl+S megnyomásával.  Nyomjon &lt;b&gt;Ctrl+Q-t&lt;/b&gt; a folytatáshoz.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1106"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Nincs elérhető billentyűzet-átalakító.  Hiányzik az információ, amely a billentyű lenyomások a terminálhoz küldendő karakterekké alakításához szükséges.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2994"/>
        <source>Show Details...</source>
        <translation>Részletek megjelenítése...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>Névtelen Színséma</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>Elérhető színséma</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="522"/>
        <source>Open Link</source>
        <translation>Link megnyitása</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="523"/>
        <source>Copy Link Address</source>
        <translation>Link másolása</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="527"/>
        <source>Send Email To...</source>
        <translation>Email küldése ...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="528"/>
        <source>Copy Email Address</source>
        <translation>Email cím másolása</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="465"/>
        <source>Color Scheme Error</source>
        <translation>Színséma hiba</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="466"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Nem sikerült betölteni a színsémát. %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="39"/>
        <source>Match case</source>
        <translation>Nagybetűérzékeny</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="45"/>
        <source>Regular expression</source>
        <translation>Reguláris kifejezés</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="49"/>
        <source>Highlight all matches</source>
        <translation>Találatok kiemelése</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Keresősáv</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation></translation>
    </message>
</context>
</TS>
